@@ -19,7 +19,7 @@ from pip._vendor.packaging import specifiers
 from pip._vendor.packaging.markers import Marker
 from pip._vendor.packaging.requirements import InvalidRequirement, Requirement
 from pip._vendor.packaging.utils import canonicalize_name
-from pip._vendor.packaging.version import Version
+from pip._vendor.packaging.version import Version, parse as parse_version
 from pip._vendor.six.moves import configparser
 
 import pip.wheel
@@ -40,7 +40,7 @@ from pip.utils import (
 )
 
 from pip.utils.hashes import Hashes
-from pip.utils.deprecation import RemovedInPip9Warning, RemovedInPip10Warning
+from pip.utils.deprecation import RemovedInPip10Warning
 from pip.utils.logging import indent_log
 from pip.utils.setuptools_build import SETUPTOOLS_SHIM
 from pip.utils.ui import open_spinner
@@ -66,6 +66,10 @@ def _strip_extras(path):
     return path_no_extras, extras
 
 
+def _safe_extras(extras):
+    return set(pkg_resources.safe_extra(extra) for extra in extras)
+
+
 class InstallRequirement(object):
 
     def __init__(self, req, comes_from, source_dir=None, editable=False,
@@ -85,7 +89,7 @@ class InstallRequirement(object):
                     add_msg = traceback.format_exc()
                 raise InstallationError(
                     "Invalid requirement: '%s'\n%s" % (req, add_msg))
-            self.extras = req.extras
+            self.extras = _safe_extras(req.extras)
 
         self.req = req
         self.comes_from = comes_from
@@ -96,7 +100,10 @@ class InstallRequirement(object):
         self._wheel_cache = wheel_cache
         self.link = self.original_link = link
         self.as_egg = as_egg
-        self.markers = markers
+        if markers is not None:
+            self.markers = markers
+        else:
+            self.markers = req and req.marker
         self._egg_info_path = None
         # This holds the pkg_resources.Distribution object if this requirement
         # is already available:
@@ -149,7 +156,7 @@ class InstallRequirement(object):
                   wheel_cache=wheel_cache)
 
         if extras_override is not None:
-            res.extras = extras_override
+            res.extras = _safe_extras(extras_override)
 
         return res
 
@@ -171,6 +178,8 @@ class InstallRequirement(object):
             markers = markers.strip()
             if not markers:
                 markers = None
+            else:
+                markers = Marker(markers)
         else:
             markers = None
         name = name.strip()
@@ -226,7 +235,8 @@ class InstallRequirement(object):
                   wheel_cache=wheel_cache, constraint=constraint)
 
         if extras:
-            res.extras = Requirement('placeholder' + extras).extras
+            res.extras = _safe_extras(
+                Requirement('placeholder' + extras).extras)
 
         return res
 
@@ -307,7 +317,12 @@ class InstallRequirement(object):
             # package is not available yet so we create a temp directory
             # Once run_egg_info will have run, we'll be able
             # to fix it via _correct_build_location
-            self._temp_build_dir = tempfile.mkdtemp('-build', 'pip-')
+            # Some systems have /tmp as a symlink which confuses custom
+            # builds (such as numpy). Thus, we ensure that the real path
+            # is returned.
+            self._temp_build_dir = os.path.realpath(
+                tempfile.mkdtemp('-build', 'pip-')
+            )
             self._ideal_build_dir = build_dir
             return self._temp_build_dir
         if self.editable:
@@ -421,13 +436,10 @@ class InstallRequirement(object):
                 egg_info_cmd + egg_base_option,
                 cwd=self.setup_py_dir,
                 show_stdout=False,
-                command_level=logging.DEBUG,
                 command_desc='python setup.py egg_info')
 
         if not self.req:
-            if isinstance(
-                    pkg_resources.parse_version(self.pkg_info()["Version"]),
-                    Version):
+            if isinstance(parse_version(self.pkg_info()["Version"]), Version):
                 op = "=="
             else:
                 op = "==="
@@ -482,7 +494,7 @@ class InstallRequirement(object):
                         # Don't search in anything that looks like a virtualenv
                         # environment
                         if (
-                                os.path.exists(
+                                os.path.lexists(
                                     os.path.join(root, dir, 'bin', 'python')
                                 ) or
                                 os.path.exists(
@@ -678,6 +690,10 @@ class InstallRequirement(object):
                                             'easy-install.pth')
             paths_to_remove.add_pth(easy_install_pth, './' + easy_install_egg)
 
+        elif egg_info_exists and dist.egg_info.endswith('.dist-info'):
+            for path in pip.wheel.uninstallation_paths(dist):
+                paths_to_remove.add(path)
+
         elif develop_egg_link:
             # develop egg
             with open(develop_egg_link, 'r') as fh:
@@ -691,10 +707,6 @@ class InstallRequirement(object):
                                             'easy-install.pth')
             paths_to_remove.add_pth(easy_install_pth, dist.location)
 
-        elif egg_info_exists and dist.egg_info.endswith('.dist-info'):
-            for path in pip.wheel.uninstallation_paths(dist):
-                paths_to_remove.add(path)
-
         else:
             logger.debug(
                 'Not sure how to uninstall: %s - Check: %s',
@@ -765,8 +777,8 @@ class InstallRequirement(object):
         archive_path = os.path.join(build_dir, archive_name)
         if os.path.exists(archive_path):
             response = ask_path_exists(
-                'The file %s exists. (i)gnore, (w)ipe, (b)ackup ' %
-                display_path(archive_path), ('i', 'w', 'b'))
+                'The file %s exists. (i)gnore, (w)ipe, (b)ackup, (a)bort ' %
+                display_path(archive_path), ('i', 'w', 'b', 'a'))
             if response == 'i':
                 create_archive = False
             elif response == 'w':
@@ -780,6 +792,8 @@ class InstallRequirement(object):
                     display_path(dest_file),
                 )
                 shutil.move(archive_path, dest_file)
+            elif response == 'a':
+                sys.exit(-1)
         if create_archive:
             zip = zipfile.ZipFile(
                 archive_path, 'w', zipfile.ZIP_DEFLATED,
@@ -812,9 +826,15 @@ class InstallRequirement(object):
         name = name.replace(os.path.sep, '/')
         return name
 
-    def match_markers(self):
+    def match_markers(self, extras_requested=None):
+        if not extras_requested:
+            # Provide an extra to safely evaluate the markers
+            # without matching any extra
+            extras_requested = ('',)
         if self.markers is not None:
-            return Marker(self.markers).evaluate()
+            return any(
+                self.markers.evaluate({'extra': extra})
+                for extra in extras_requested)
         else:
             return True
 
@@ -846,30 +866,8 @@ class InstallRequirement(object):
         temp_location = tempfile.mkdtemp('-record', 'pip-')
         record_filename = os.path.join(temp_location, 'install-record.txt')
         try:
-            install_args = [sys.executable, "-u"]
-            install_args.append('-c')
-            install_args.append(SETUPTOOLS_SHIM % self.setup_py)
-            install_args += list(global_options) + \
-                ['install', '--record', record_filename]
-
-            if not self.as_egg:
-                install_args += ['--single-version-externally-managed']
-
-            if root is not None:
-                install_args += ['--root', root]
-            if prefix is not None:
-                install_args += ['--prefix', prefix]
-
-            if self.pycompile:
-                install_args += ["--compile"]
-            else:
-                install_args += ["--no-compile"]
-
-            if running_under_virtualenv():
-                py_ver_str = 'python' + sysconfig.get_python_version()
-                install_args += ['--install-headers',
-                                 os.path.join(sys.prefix, 'include', 'site',
-                                              py_ver_str, self.name)]
+            install_args = self.get_install_args(
+                global_options, record_filename, root, prefix)
             msg = 'Running setup.py install for %s' % (self.name,)
             with open_spinner(msg) as spinner:
                 with indent_log():
@@ -942,6 +940,34 @@ class InstallRequirement(object):
             self.source_dir = self.build_location(parent_dir)
         return self.source_dir
 
+    def get_install_args(self, global_options, record_filename, root, prefix):
+        install_args = [sys.executable, "-u"]
+        install_args.append('-c')
+        install_args.append(SETUPTOOLS_SHIM % self.setup_py)
+        install_args += list(global_options) + \
+            ['install', '--record', record_filename]
+
+        if not self.as_egg:
+            install_args += ['--single-version-externally-managed']
+
+        if root is not None:
+            install_args += ['--root', root]
+        if prefix is not None:
+            install_args += ['--prefix', prefix]
+
+        if self.pycompile:
+            install_args += ["--compile"]
+        else:
+            install_args += ["--no-compile"]
+
+        if running_under_virtualenv():
+            py_ver_str = 'python' + sysconfig.get_python_version()
+            install_args += ['--install-headers',
+                             os.path.join(sys.prefix, 'include', 'site',
+                                          py_ver_str, self.name)]
+
+        return install_args
+
     def remove_temporary_source(self):
         """Remove the source files from this requirement, if they are marked
         for deletion"""
@@ -997,6 +1023,12 @@ class InstallRequirement(object):
             no_marker = Requirement(str(self.req))
             no_marker.marker = None
             self.satisfied_by = pkg_resources.get_distribution(str(no_marker))
+            if self.editable and self.satisfied_by:
+                self.conflicts_with = self.satisfied_by
+                # when installing editables, nothing pre-existing should ever
+                # satisfy
+                self.satisfied_by = None
+                return True
         except pkg_resources.DistributionNotFound:
             return False
         except pkg_resources.VersionConflict:
@@ -1087,24 +1119,6 @@ def _strip_postfix(req):
     return req
 
 
-def _build_req_from_url(url):
-
-    parts = [p for p in url.split('#', 1)[0].split('/') if p]
-
-    req = None
-    if len(parts) > 2 and parts[-2] in ('tags', 'branches', 'tag', 'branch'):
-        req = parts[-3]
-    elif len(parts) > 1 and parts[-1] == 'trunk':
-        req = parts[-2]
-    if req:
-        warnings.warn(
-            'Sniffing the requirement name from the url is deprecated and '
-            'will be removed in the future. Please specify an #egg segment '
-            'instead.', RemovedInPip9Warning,
-            stacklevel=2)
-    return req
-
-
 def parse_editable(editable_req, default_vcs=None):
     """Parses an editable requirement into:
         - a requirement name
@@ -1144,7 +1158,7 @@ def parse_editable(editable_req, default_vcs=None):
             return (
                 package_name,
                 url_no_extras,
-                Requirement("placeholder" + extras).extras,
+                Requirement("placeholder" + extras.lower()).extras,
             )
         else:
             return package_name, url_no_extras, None
@@ -1156,6 +1170,11 @@ def parse_editable(editable_req, default_vcs=None):
 
     if '+' not in url:
         if default_vcs:
+            warnings.warn(
+                "--default-vcs has been deprecated and will be removed in "
+                "the future.",
+                RemovedInPip10Warning,
+            )
             url = default_vcs + '+' + url
         else:
             raise InstallationError(
@@ -1174,7 +1193,9 @@ def parse_editable(editable_req, default_vcs=None):
 
     package_name = Link(url).egg_fragment
     if not package_name:
-        package_name = _build_req_from_url(editable_req)
+        raise InstallationError(
+            "Could not detect requirement name, please specify one with #egg="
+        )
     if not package_name:
         raise InstallationError(
             '--editable=%s is not the right format; it must have '
